local key_covariates "lhwage lmwage eta dummy_ed1 dummy_ed2 dummy_ed3 dummy_ed4 operaio impiegato manager sposato mammapub papapub mammahigh papahigh mammalow papalow risfinlow risfinhigh"


use "${final_data}/dataset_analysis", clear
gen pub2=(dimaz==7) if dimaz!=.
tab anno pub [iw=pesofl2] if qualp10<5, 
tab anno pub2 [iw=pesofl2] if qualp10<5, 
tab pub pub2 /*[iw=pesofl2]*/ if qualp10<5

table anno pub [iw=pesofl2],c(mean oretot median oretot)

/*=============================================
EVOLUTION OF PUBLIC SCETOR
=============================================*/

	* by gender
use "${final_data}/dataset_analysis",clear
keep if anno>=${init_year}
gen uno=1
collapse (sum) uno [aw=pesofit],by(pub sesso anno)
egen tot=total(uno),by(sesso anno)
gen share=uno/tot
drop uno tot
reshape wide share,i(anno sesso) j(pub)
ren share0 share_pub0
ren share1 share_pub1
reshape wide share_pub0 share_pub1,i(anno) j(sesso)
keep if anno>=${init_year}
save tmp,replace
	* aggregate
use "${final_data}/dataset_analysis",clear
keep if anno>=${init_year}
gen uno=1
collapse (sum) uno [aw=pesofit],by(pub anno)
egen tot=total(uno),by(anno)
gen share=uno/tot
drop uno tot
reshape wide share,i(anno) j(pub)
ren share0 share_tot0
ren share1 share_tot1
keep if anno>=${init_year}
merge 1:1 anno using tmp
drop _merge 
format share* %9.3f
gen fine  ="\cr"
outsheet anno share_pub00 share_pub10 share_pub01 share_pub11 share_tot0 share_tot1 fine using "${results}/evolution_public.tex", ///
	nolabel noquote nonames delimit("&") replace
erase tmp.dta

/*=============================================
KEY COVARIATES
=============================================*/

local functional "mean p10 median p90 sd"
foreach ffff of local functional {
	local reshaping ""
	use "${final_data}/dataset_analysis",clear
	keep if anno>=${init_year}
	replace dummy_ed2=dummy_ed1 + dummy_ed2
	collapse (`ffff') `key_covariates' [aw=pesofit], by(pub sesso)
	reshape wide `key_covariates',i(sesso) j(pub)
	foreach lsdf of local key_covariates {
		ren `lsdf'0 `lsdf'_pub0_sex
		ren `lsdf'1 `lsdf'_pub1_sex
		local reshaping "`reshaping' `lsdf'_pub0_sex `lsdf'_pub1_sex"
	}
	gen uno=1
	reshape wide `reshaping',i(uno) j(sesso)
	local lknmon=0
	foreach lsdf of local key_covariates {
		local lknmon=`lknmon'+1
		ren `lsdf'_pub0_sex0 pub0_sex0`lknmon'
		ren `lsdf'_pub0_sex1 pub0_sex1`lknmon'
		ren `lsdf'_pub1_sex0 pub1_sex0`lknmon'
		ren `lsdf'_pub1_sex1 pub1_sex1`lknmon'
	}
	reshape long pub0_sex0 pub1_sex0 pub0_sex1 pub1_sex1,i(uno) j(desvar)
	ren pub0_sex0 `ffff'pub0_sex0
	ren pub1_sex0 `ffff'pub1_sex0
	ren pub0_sex1 `ffff'pub0_sex1
	ren pub1_sex1 `ffff'pub1_sex1
	drop uno
	save `ffff', replace
}

foreach ffff of local functional {
	use `ffff', replace
	cap merge 1:1 desvar using descriptive
	cap drop _merge
	save descriptive,replace
	erase `ffff'.dta
	
}

format _all %9.2f
gen fine ="\cr"
save descriptive,replace


use "${final_data}/dataset_analysis",clear
local lknmon=0
foreach lsdf of local key_covariates {
	local lknmon=`lknmon' +1 

	ttest `lsdf' if sesso==0,by(pub)
	mat tttest0=nullmat(tttest0) \ `lknmon' , r(t),r(p)

	ttest `lsdf' if sesso==1,by(pub)
	mat tttest1=nullmat(tttest1) \ `lknmon' , r(t),r(p)
}
clear
svmat tttest0
svmat tttest1
ren tttest01 desvar
drop tttest11
format tttest* %9.3f
merge 1:1 desvar using descriptive
save descriptive,replace

use descriptive,clear
label define desvar 1 "ln(Hourly wage)" 2 "ln(Monthly wage)" 3 "Age" 4 "%Basic ed." 5 "Low ed." 6 "High ed." 7 "BA" ///
	8 "Blue collar" 9 "White collar" 10 "Manager" 11 "Married" ///
	12 "Mother pub." 13 "Father pub." 14 "Mother high ed." 15 "Father high ed." 16 "Mother low ed." 17 "Father low ed." 18 "Low risk" 19 "High risk" 
label value desvar desvar
keep desvar *sex0 tttest03 fine
order desvar meanpub0_sex0 sdpub0_sex0 p10pub0_sex0 medianpub0_sex0 p90pub0_sex0 ///
	meanpub1_sex0 sdpub1_sex0 p10pub1_sex0 medianpub1_sex0 p90pub1_sex0 tttest03 fine
outsheet  using "${results}/descriptive_women.tex", ///
	noquote nonames delimit("&") replace
use descriptive,clear
label define desvar 1 "&\multicolumn{10}{c|}{Outcomes}\cr ln(Hourly wage)" 2 "ln(Monthly wage)" 3 "&\multicolumn{10}{c|}{Adjusting variables}\cr Age" 4 "%Basic ed." 5 "Low ed." 6 "High ed." 7 "BA" ///
	8 "Blue collar" 9 "White collar" 10 "Manager" 11 "Married" ///
	12 "&\multicolumn{10}{c|}{Candidate Intruments}\cr Mother pub." 13 "Father pub." 14 "Mother high ed." 15 "Father high ed." 16 "Mother low ed." 17 "Father low ed." 18 "Low risk" 19 "High risk" 
label value desvar desvar
keep desvar *sex1 tttest13 fine
order desvar meanpub0_sex1 sdpub0_sex1 p10pub0_sex1 medianpub0_sex1 p90pub0_sex1 ///
	 meanpub1_sex1 sdpub1_sex1 p10pub1_sex1 medianpub1_sex1 p90pub1_sex1 tttest13  fine
outsheet  using "${results}/descriptive_men.tex", ///
	noquote nonames delimit("&") replace
 
erase descriptive.dta
mat drop tttest0
mat drop tttest1

/*=============================================
correlation parent (sector,schooling)
=============================================*/
use "${final_data}/dataset_analysis",clear
qui do "${dofiles}/adjusting_sample"	
keep if anno>=${init_year}
corr mammapub papapub mammahigh papahigh mammalow papalow pub
mata mata clear
putmata mammapub papapub mammahigh papahigh mammalow papalow pub
mata x=(mammapub ,papapub, mammahigh ,papahigh, mammalow ,papalow ,pub)
mata var=corr(cross(x,x))
clear
getmata (mammapub papapub mammahigh papahigh mammalow papalow pub)=var
format mammapub papapub mammahigh papahigh mammalow papalow pub %9.3f
gen fine  ="\cr"
outsheet mammapub papapub mammahigh papahigh mammalow papalow pub fine using "${results}/correlation_parent_sector_schooling.tex", ///
	nolabel noquote nonames delimit("&") replace

/*
/*=============================================
RISK INDICATOR
=============================================*/
use "${final_data}/dataset_analysis",clear
gen uno=1
collapse (sum) uno,by(anno risfin pub)
egen tot=total(uno),by(anno pub)
gen share=uno*100/tot
drop uno tot
reshape wide share,i(anno pub) j(risfin)
reshape wide share0 share1 share2 share3 share4 , i(anno) j(pub)
keep if anno>=2006
format share* %9.1f
outsheet  using "${results}/descriptive_risk.tex", ///
	noquote nonames delimit("&") replace
*/


