/*
RATIONAL:
pag 11 in Chernozhukov, Hansen reads that 
"similarity [...] states that given the information
in (V;X;Z) employed to make the selection of treatment D, the expectations of any function
of rank Ud does not vary across the treatment states. That is, ex-ante, conditional on
(V;X;Z), the ranks may be considered to be the same across potential treatments, but the
realized, ex-post, rank may be different across treatment states."

This suggests the following simple approach:
allocate people within cells defined according to relevant covariates (here I followed the Mincer equation) 
for group 0 and group 1
If rank invariance holds than the scatter plot within cells will be equal
*/
foreach lkdfjlgj of local variousinst {
	cap log close
	qui log using "${results}/${name}_rank_invariance_`lkdfjlgj'.txt",text replace
	qui log off
	foreach pppp of numlist  25 50 75 {
			use "${final_data}/dataset_analysis",clear
			qui do "${dofiles}/adjusting_sample"	
			keep if anno>=2006
			keep if `lkdfjlgj'==1
			gen uno=1
			collapse (p`pppp') ${dep} (sum) uno,by(pub eta_reg dummy_ed1 dummy_ed2 dummy_ed3 sesso)
			reshape wide ${dep} uno, i( eta_reg dummy_ed1 dummy_ed2 dummy_ed3 sesso) j(pub)
			egen uno=rowtotal(uno0 uno1)
			reg ${dep}0 ${dep}1 [fw=uno] if sesso==1
			est store cons_rm
			reg ${dep}0 ${dep}1 [fw=uno] if sesso==0
			est store cons_rw
			reg ${dep}0 ${dep}1 [fw=uno] if sesso==1,nocons
			est store nocons_rm
			reg ${dep}0 ${dep}1 [fw=uno] if sesso==0,nocons
			est store nocons_rw
			qui log on
			di "***************************************"
			di "Quantile: `pppp'"
			di "***************************************"
			corr ${dep}0 ${dep}1 [fw=uno] if sesso==0
			corr ${dep}0 ${dep}1 [fw=uno] if sesso==1
			est tab cons_rm nocons_rm cons_rw nocons_rw
			qui log off
	}
	qui {
	foreach pppp of numlist 25 50 75 {
		forvalues shgf=0/1 {
			use "${final_data}/dataset_analysis",clear
			qui do "${dofiles}/adjusting_sample"	
			keep if anno>=2006
			keep if `lkdfjlgj'==1
			keep if sesso==`shgf'
			gen uno=1
			collapse (p`pppp') ${dep} (sum) uno ,by(pub eta_reg dummy_ed1 dummy_ed2 dummy_ed3 )
			reshape wide ${dep} uno, i( eta_reg dummy_ed1 dummy_ed2 dummy_ed3 ) j(pub)
			egen uno=rowtotal(uno0 uno1)
			reg ${dep}0 ${dep}1	,nocon
			predict xb,xb
			corr ${dep}0 ${dep}1	[fw=uno] 
			reg ${dep}0 ${dep}1 [fw=uno] ,nocon
			*gen corr=r(rho)
			gen corr=_b[${dep}1]
			format corr %9.3f
			tostring corr,replace force used
			codebook corr
			local corr=`r(cons)'
			tw (scatter ${dep}0 ${dep}1,yti("Private") xti("Public") caption("{&rho}=`corr'",position(11) ring(0) size(large)) ) ///
				(line xb ${dep}1), leg(off)
			gr export "${results}/${name}_rank_invariance_`lkdfjlgj'_sesso`shgf'_q`pppp'.png",replace
		}
	}
	}
}	
	
gr drop _all
