clear all
use "${final_data}/dataset_analysis",clear
qui do "${dofiles}/adjusting_sample"	
qui tab anno,gen(d)
drop if edu<=1		

mata: mata clear

gen gruppo=1
reg ${dep} ${covariates_iv} pub papapub if sesso==1 
keep if e(sample)==1
sum gruppo
local gruppi=r(max)

gen uno=1
forvalues hfbhn = 1 / `gruppi' {
	preserve
	keep if gruppo==`hfbhn'
	centile(lhwage), centile(3 97)
	scalar UB=r(c_2)
	scalar LB=r(c_1)

	gen Z=papapub
	gen D=pub
	egen c1=mean(Z)
	gen c0=1-c1
	gen T = LB+ 0.01*_n
	replace T=. if T>UB

	sum edu
	local edu=r(min)
	sum anno
	local ann=r(min)
	sum area5
	local are=r(min)
	gen Ybar1 = c1*D*(1-Z)-c0*D*Z
	gen Ybar2 = c0*(1-D)*Z-c1*(1-D)*(1-Z)

	cap noi clrtest (Ybar1 lhwage T) (Ybar2 lhwage T), met("series") level(0.5 0.9 0.95 0.99  0.995)
	mat clr=nullmat(clr) \ 1,`ann',`are',(e(det50)),(e(det90)),(e(det95)),(e(det99),(e(det995)))
	restore
}
clear
svmat clr
save tmp,replace

***********************************
***********************************
***********************************
* education only
***********************************
***********************************
***********************************
clear all
use "${final_data}/dataset_analysis",clear
qui do "${dofiles}/adjusting_sample"	
qui tab anno,gen(d)

mata: mata clear

egen gruppo=group(education )
reg ${dep} ${covariates_iv} pub papapub if sesso==1 
keep if e(sample)==1
sum gruppo
local gruppi=r(max)

gen uno=1
forvalues hfbhn = 1 / `gruppi' {
	preserve
	keep if gruppo==`hfbhn'
	centile(lhwage), centile(3 97)
	scalar UB=r(c_2)
	scalar LB=r(c_1)

	gen Z=papapub
	gen D=pub
	egen c1=mean(Z)
	gen c0=1-c1
	gen T = LB+ 0.01*_n
	replace T=. if T>UB

	sum edu
	local edu=r(min)
	sum anno
	local ann=r(min)
	sum area5
	local are=r(min)
	gen Ybar1 = c1*D*(1-Z)-c0*D*Z
	gen Ybar2 = c0*(1-D)*Z-c1*(1-D)*(1-Z)

	cap noi clrtest (Ybar1 lhwage T) (Ybar2 lhwage T), met("series") level(0.5 0.9 0.95 0.99  0.995)
	mat clr=nullmat(clr) \ `edu',`ann',`are',(e(det50)),(e(det90)),(e(det95)),(e(det99),(e(det995)))
	restore
}
clear
svmat clr
ren clr4 ci50_
ren clr5 ci90_
ren clr6 ci95_
ren clr7 ci99_
ren clr8 ci100_
reshape wide ci50 ci90 ci95 ci99 ci100,i(clr2) j(clr1)
drop clr3
save school,replace

use school,replace
merge 1:1 clr2 using tmp
drop *_1
drop *50_*
drop clr2
gen intesto="Pool"
order intest
gen fine  ="\cr"
outsheet using "${results}/table_mourifiewan_pool.tex", ///
	 noquote nonames delimit("&") replace


erase tmp.dta
erase school.dta

***********************************
***********************************
***********************************
* <2012
***********************************
***********************************
***********************************
clear all
use "${final_data}/dataset_analysis",clear
qui do "${dofiles}/adjusting_sample"	
qui tab anno,gen(d)
drop if edu<=1		

mata: mata clear

gen gruppo=1
keep if anno<2012
reg ${dep} ${covariates_iv} pub papapub if sesso==1 
keep if e(sample)==1
sum gruppo
local gruppi=r(max)

gen uno=1
forvalues hfbhn = 1 / `gruppi' {
	preserve
	keep if gruppo==`hfbhn'
	centile(lhwage), centile(3 97)
	scalar UB=r(c_2)
	scalar LB=r(c_1)

	gen Z=papapub
	gen D=pub
	egen c1=mean(Z)
	gen c0=1-c1
	gen T = LB+ 0.01*_n
	replace T=. if T>UB

	sum edu
	local edu=r(min)
	sum anno
	local ann=r(min)
	sum area5
	local are=r(min)
	gen Ybar1 = c1*D*(1-Z)-c0*D*Z
	gen Ybar2 = c0*(1-D)*Z-c1*(1-D)*(1-Z)

	cap noi clrtest (Ybar1 lhwage T) (Ybar2 lhwage T), met("series") level(0.5 0.9 0.95 0.99  0.995)
	mat clr=nullmat(clr) \ 1,`ann',`are',(e(det50)),(e(det90)),(e(det95)),(e(det99),(e(det995)))
	restore
}
clear
svmat clr
save "${results}/iv_validity_mourifiewan_no2012", replace



***********************************
***********************************
* 2006-2008
***********************************
***********************************
***********************************
clear all
use "${final_data}/dataset_analysis",clear
qui do "${dofiles}/adjusting_sample"	
qui tab anno,gen(d)
drop if edu<=1		

mata: mata clear

gen gruppo=1
keep if anno==2006|anno==2008
reg ${dep} ${covariates_iv} pub papapub if sesso==1 
keep if e(sample)==1
sum gruppo
local gruppi=r(max)

gen uno=1
forvalues hfbhn = 1 / `gruppi' {
	preserve
	keep if gruppo==`hfbhn'
	centile(lhwage), centile(3 97)
	scalar UB=r(c_2)
	scalar LB=r(c_1)

	gen Z=papapub
	gen D=pub
	egen c1=mean(Z)
	gen c0=1-c1
	gen T = LB+ 0.01*_n
	replace T=. if T>UB

	sum edu
	local edu=r(min)
	sum anno
	local ann=r(min)
	sum area5
	local are=r(min)
	gen Ybar1 = c1*D*(1-Z)-c0*D*Z
	gen Ybar2 = c0*(1-D)*Z-c1*(1-D)*(1-Z)

	cap noi clrtest (Ybar1 lhwage T) (Ybar2 lhwage T), met("series") level(0.5 0.9 0.95 0.99  0.995)
	mat clr=nullmat(clr) \ 1,`ann',`are',(e(det50)),(e(det90)),(e(det95)),(e(det99),(e(det995)))
	restore
}
clear
svmat clr
save "${results}/iv_validity_mourifiewan_2006_2008", replace

***********************************
***********************************
***********************************
* 2006-2008
***********************************
***********************************
***********************************
clear all
use "${final_data}/dataset_analysis",clear
qui do "${dofiles}/adjusting_sample"	
qui tab anno,gen(d)
drop if edu<=1		

mata: mata clear

gen gruppo=1
keep if anno==2010|anno==2012
reg ${dep} ${covariates_iv} pub papapub if sesso==1 
keep if e(sample)==1
sum gruppo
local gruppi=r(max)

gen uno=1
forvalues hfbhn = 1 / `gruppi' {
	preserve
	keep if gruppo==`hfbhn'
	centile(lhwage), centile(3 97)
	scalar UB=r(c_2)
	scalar LB=r(c_1)

	gen Z=papapub
	gen D=pub
	egen c1=mean(Z)
	gen c0=1-c1
	gen T = LB+ 0.01*_n
	replace T=. if T>UB

	sum edu
	local edu=r(min)
	sum anno
	local ann=r(min)
	sum area5
	local are=r(min)
	gen Ybar1 = c1*D*(1-Z)-c0*D*Z
	gen Ybar2 = c0*(1-D)*Z-c1*(1-D)*(1-Z)

	cap noi clrtest (Ybar1 lhwage T) (Ybar2 lhwage T), met("series") level(0.5 0.9 0.95 0.99  0.995)
	mat clr=nullmat(clr) \ 1,`ann',`are',(e(det50)),(e(det90)),(e(det95)),(e(det99),(e(det995)))
	restore
}
clear
svmat clr
save "${results}/iv_validity_mourifiewan_2010_2012", replace
