*=============================================
*	SETTINGS
*=============================================
clear all
set more off
set seed 150180
cap cd "\\Osiride-fs\c155300\public_private_bounds"
cap cd "public_private_bounds"
global orig_data 	 	"/home/group/main/894ic/famiglie"
global orig_data_storico 	"${orig_data}/storico/dati/stata"
global orig_data_cross	 	"${orig_data}"
global final_data 		"data"
global dofiles 			"dofiles_jae"
global results 			"dofiles_jae/result"

global tex_fmt="fmt(%9.3f)"

global covariates		"eta_reg eta_reg2 sesso sposato  dummy_ed1 dummy_ed2 dummy_ed3  operaio manager partime  dummy_area1 dummy_area2 dummy_area4 dummy_area5 pub "
global covariates_iv		"eta_reg eta_reg2 sesso sposato  dummy_ed1 dummy_ed2 dummy_ed3  operaio manager partime  dummy_area1 dummy_area2 dummy_area4 dummy_area5"
*global covariates		"partime sposato eta_reg eta_reg2 dummy_ed1 dummy_ed2 dummy_ed3 sesso dummy_area1 dummy_area2 dummy_area4 dummy_area5 pub "
*global covariates_iv		"partime sposato eta_reg eta_reg2 dummy_ed1 dummy_ed2 dummy_ed3 sesso dummy_area1 dummy_area2 dummy_area4 dummy_area5 "
global init_year=		2006
global reps=			500

adopath +			"${dofiles}/ado"

*=============================================
*	DATA
*=============================================
*qui do "${dofiles}/getting_data"


*=============================================
*	ANALYSIS
*=============================================
qui do "${dofiles}/descriptive"

	* Benchmark
global dep		"lhwage" 
global name 		"bench"
global adjusting_sample ""
local variousinst "mammapub papapub mammahigh papahigh mammalow papalow risfinlow risfinhigh"
do "${dofiles}/ols_analysis"
include "${dofiles}/iv_analysis"
include "${dofiles}/iv_instrument_decision"
include "${dofiles}/iv_validity_analysis"
include "${dofiles}/iv_rank_invariance"
include "${dofiles}/iv_pqd"
do "${dofiles}/iv_j_test"
include "${dofiles}/bounds_analysis"
include "${dofiles}/bounds_explaining_widths"
include "${dofiles}/iv_characterizing_compliers"	// This is only for benchmark
include "${dofiles}/bounds_analysis_manski_pepper"	// This is only for benchmark
include "${dofiles}/iv_validity_mourifiewan_unconditional"			// This is only for benchmark
include "${dofiles}/iv_validity_mourifiewan_noyear.do"
include "${dofiles}/iv_rank_invariance_bis"		// This is only for benchmark
gr drop _all
mat drop _all

	* Old workers
global dep		"lhwage" 
global name 		"old"
global adjusting_sample "keep if eta>40 "
local variousinst "mammapub papapub mammahigh papahigh mammalow papalow risfinlow risfinhigh"
do "${dofiles}/ols_analysis"
include "${dofiles}/iv_analysis"
include "${dofiles}/iv_instrument_decision"
include "${dofiles}/iv_validity_analysis"
include "${dofiles}/iv_rank_invariance"
include "${dofiles}/iv_pqd"
do "${dofiles}/iv_j_test"
include "${dofiles}/bounds_analysis"
include "${dofiles}/bounds_explaining_widths"
gr drop _all
mat drop _all

	* Young workers
global dep		"lhwage" 
global name 		"young"
global adjusting_sample "keep if eta<=40 "
local variousinst "mammapub papapub mammahigh papahigh mammalow papalow risfinlow risfinhigh"
do "${dofiles}/ols_analysis"
include "${dofiles}/iv_analysis"
include "${dofiles}/iv_instrument_decision"
include "${dofiles}/iv_validity_analysis"
include "${dofiles}/iv_rank_invariance"
include "${dofiles}/iv_pqd"
do "${dofiles}/iv_j_test"
include "${dofiles}/bounds_analysis"
include "${dofiles}/bounds_explaining_widths"
gr drop _all
mat drop _all


	* Minimum wage
global dep		"lhwage" 
global name 		"minwage"
global adjusting_sample "keep if exp(lhwage)>5 "
local variousinst "mammapub papapub mammahigh papahigh mammalow papalow risfinlow risfinhigh"
do "${dofiles}/ols_analysis"
include "${dofiles}/iv_analysis"
include "${dofiles}/iv_instrument_decision"
include "${dofiles}/iv_validity_analysis"
include "${dofiles}/iv_rank_invariance"
include "${dofiles}/iv_pqd"
do "${dofiles}/iv_j_test"
include "${dofiles}/bounds_analysis"
include "${dofiles}/bounds_explaining_widths"
gr drop _all
mat drop _all

	* EDUCATION / HOURLY DEF
forvalues edddd =2/4 {
	global dep		"lhwage" 
	global name 		"edu`edddd'"
	global adjusting_sample "keep if education==`edddd' "
	local variousinst "mammapub papapub mammahigh papahigh mammalow papalow risfinlow risfinhigh"
	if `edddd'==2 local variousinst "mammapub papapub papahigh mammalow papalow risfinlow risfinhigh"
	if `edddd'==4 local variousinst "mammapub papapub mammahigh papahigh"
	do "${dofiles}/ols_analysis"
	include "${dofiles}/iv_analysis"
	include "${dofiles}/iv_instrument_decision"
	include "${dofiles}/iv_validity_analysis"
	include "${dofiles}/iv_rank_invariance"
	include "${dofiles}/iv_pqd"
	do "${dofiles}/iv_j_test"
	include "${dofiles}/bounds_analysis"
	gr drop _all
	mat drop _all
}

	* EDUCATION / monthly DEF
forvalues edddd =2/4 {
	global dep		"lmwage" 
	global name 		"month_edu`edddd'"
	global adjusting_sample "keep if education==`edddd' "
	local variousinst "mammapub papapub mammahigh papahigh mammalow papalow risfinlow risfinhigh"
	if `edddd'==2 local variousinst "mammapub papapub papahigh mammalow papalow risfinlow risfinhigh"
	if `edddd'==4 local variousinst "mammapub papapub mammahigh papahigh"
	do "${dofiles}/ols_analysis"
	include "${dofiles}/iv_analysis"
	include "${dofiles}/iv_instrument_decision"
	include "${dofiles}/iv_validity_analysis"
	include "${dofiles}/iv_rank_invariance"
	include "${dofiles}/iv_pqd"
	do "${dofiles}/iv_j_test"
	include "${dofiles}/bounds_analysis"
	gr drop _all
	mat drop _all
}

	* Monthly wage definition
global covariates		"oretot eta_reg eta_reg2 sesso sposato  dummy_ed1 dummy_ed2 dummy_ed3  operaio manager partime  dummy_area1 dummy_area2 dummy_area4 dummy_area5 pub "
global covariates_iv		"oretot eta_reg eta_reg2 sesso sposato  dummy_ed1 dummy_ed2 dummy_ed3  operaio manager partime  dummy_area1 dummy_area2 dummy_area4 dummy_area5"
*global covariates		"eta_reg eta_reg2 dummy_ed1 dummy_ed2 dummy_ed3 sesso dummy_area1 dummy_area2 dummy_area4 dummy_area5 pub "
*global covariates_iv		"eta_reg eta_reg2 dummy_ed1 dummy_ed2 dummy_ed3 sesso dummy_area1 dummy_area2 dummy_area4 dummy_area5 "
global dep		"lmwage" 
global name 		"month"
global adjusting_sample ""
local variousinst "mammapub papapub mammahigh papahigh mammalow papalow risfinlow risfinhigh"
do "${dofiles}/ols_analysis"
include "${dofiles}/iv_analysis"
include "${dofiles}/iv_instrument_decision"
include "${dofiles}/iv_validity_analysis"
include "${dofiles}/iv_rank_invariance"
include "${dofiles}/iv_pqd"
do "${dofiles}/iv_j_test"
include "${dofiles}/bounds_analysis"
include "${dofiles}/bounds_explaining_widths"
gr drop _all
mat drop _all

