use "${final_data}/dataset",clear

* numero di figli piccoli
egen figli_piccoli=total(eta<15),by(anno nquest)
label var figli_piccoli "Children"

/*************************************
drop observations
*************************************/
* define working age
keep if eta>=20 & eta<=65

/*************************************
wage in euro
*************************************/
* define working age
replace yl=1000*yl/1936.27 if anno<2002
gen hwage=(yl/mesilav)/(4*oretot)
gen lhwage=ln(hwage)
lab var hwage "Hourly wage"
lab var lhwage "log(Hourly wage)"

gen mwage=(yl/mesilav)
gen lmwage=ln(mwage)
lab var mwage "Monthly wage"
lab var lmwage "log(Monthly wage)"


/*************************************
demographic characteristics
*************************************/
* recode sesso
replace sesso=0 if sesso==2
label define sesso 0 Women 1 Men
label value sesso sesso

* recode stato civile
recode staciv (1=1 "Married") (2 3 4=0 "Non Married"),gen(sposato)

* recode regione
label define regioni 1 Piemonte 2 "Valle d'Aosta" 3 Lombardia	///
					4 Trentino 5 Veneto 6 Friuli 7 Liguria 	///
					8 "Emilia Romagna" 9 Toscana 10 Umbria 	///
					11 Marche 12 Lazio 13 Abruzzo 14 Molise	///
					15 Campania 16 Puglia 17 Basilicata 	///
					18 Calabria 19 Sicilia 20 Sardegna
label value ireg regioni
label value nascreg regioni

* recode area
label define area3 1 N 2 C 3 S	
label value area3 area3
label value nascarea area3

label define area5 1 NW 2 NE 3 C 4 S 5 IS	
label value area5 area5

qui tab area5,gen(dummy_area)
qui tab ireg,gen(dummy_reg)

* recode classe eta
label define classe_eta 1 "<30" 2 "31--40" 3 "41--50" 4 "51--65" 5 "65+"
label value eta5 classe_eta 

* recode qualifica
label define qual_worker10  1 "Blue Collar" 2 "impiegato" 3 "impiegato direttivo" 4 "dirigente" ///
							5 "libero prof." 6 "imprenditore ind." 7 "Lav.Autonomo" 8 "Impresa fam." ///
							9 "socio gestore" 10 "disoccupato"
label value qualp10 qual_worker10
label define qual_worker7n  1 "Blue Collar" 2 "impiegato" 3 "impiegato direttivo" 4 "dirigente" ///
							5 "libero prof." 6 "imprenditore ind." 7 "disoccupato"
label value qualp7n qual_worker7n
label define qual_worker3  1 "dipendente" 2 "autonomo" 3 "disoccupato"
label value qualp3 qual_worker3


* recode studio
recode studio (1 2=1 "Basic ed.") (3=2 "Lower secondary") (4=3 "Upper secondary") (5 6=4 "BA"),gen(education)
qui tab education,gen(dummy_ed)
label var dummy_ed1 "Basic ed"
label var dummy_ed2 "Low"
label var dummy_ed3 "High"
label var dummy_ed4 "BA"

* recode ampiezza
label define ampiezza 0 "<20" 1"20--40" 2 "40--500" 3 "500+"
label value acom4c ampiezza

/*************************************
income & labour characteristics
*************************************/
* indicator for workers
gen occupato=(qualp3!=3)

* indicator for dependent
gen dipendente=(qualp3==1 & occupato==1)
replace dipendente=. if occupato==0

* indicator for qualifica
gen operaio=(qualp10==1) if qualp10!=.
label var operaio "Blu collar"
gen impiegato=(qualp10==2) if qualp10!=.
label var impiegato "White collar"
gen manager=(qualp10>2 & qualp10<5) if qualp10!=.
label var manager "Manager"

* indicator for PA (definition as in Lucifora & Meurs)
*gen pub=(dimaz==7) if dimaz!=.
gen pub=(settp11==9) 

*recode partime
replace partime=1 if partime>0 & partime!=.

* recode settore
label define settore_attivita11 1 "Agriculture" 2 "Industry" 3 "Costruzioni" 4 "Commercio" ///
								5 "Trasporti" 6 "Intermediazione" 7 "Attivita immobiliari" 8 "Servizi domestici" ///
								9 "Public" 10 "Orgnismi Extra" 11 "Unemployed"
label value settp11 settore_attivita11
label define settore_attivita9 1 "Agriculture" 2 "Industry" 3 "Costruzioni" 4 "Commercio" ///
								5 "Trasporti" 6 "Intermediazione" 7 "Attivita immobiliari" 8 "PA" ///
								9 "Unemployed"
label value settp9 settore_attivita9
label define settore_attivita7 1 "Agriculture" 2 "Industry" 3 "Commercio" ///
								5 "Trasporti" 6 "PA" 7 "Attivita immobiliari" 8 "Unemployed"
label value settp7 settore_attivita7
label define settore_attivita3 1 "Agriculture" 2 "Altro" 3 "Unemployed"
label value settp3 settore_attivita3

/*************************************
exclusion restriction
*************************************/
gen mammahigh=stumamma>3 if 	stumamma!=.
label var mammahigh "Mother High ed."
gen papahigh=stupapa>3 if 	stupapa!=.
label var papahigh "Father High ed."
gen mammalow=stumamma<3 if 	stumamma!=.
label var mammalow "Mother Low ed."
gen papalow=stupapa<3 if 	stupapa!=.
label var papalow "Father Low ed."
gen risfinlow=risfin==4 if risfin!=.
label var risfinlow "Low risk"
gen risfinhigh=(risfin==1 | risfin==2) if risfin!=.
label var risfinhigh "High risk"


/*************************************
dataset definitivo
*************************************/

save "${final_data}/dataset_analysis",replace


